@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2024 Univention GmbH
+# Copyright 2013-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,12 +31,13 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+import string
 from collections.abc import Iterator
 from random import choice, randint
 
 
-STR_NUMERIC = '0123456789'
-STR_ALPHA = 'abcdefghijklmnopqrstuvwxyz'
+STR_NUMERIC = string.digits
+STR_ALPHA = string.ascii_lowercase
 STR_ALPHANUM = STR_ALPHA + STR_NUMERIC
 STR_ALPHANUMDOTDASH = STR_ALPHANUM + '.-'
 
